<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.

namespace SlackModule\Lib;


use App\Model\Table\HostsTable;
use App\Model\Table\ServicesTable;
use Cake\Datasource\EntityInterface;
use Cake\ORM\TableRegistry;
use itnovum\openITCOCKPIT\Exceptions\HostNotFoundException;
use itnovum\openITCOCKPIT\Exceptions\ServiceNotFoundException;

/**
 * Class SlackData
 * @package SlackModule\Lib
 */
class SlackData {

    /**
     * @param string $hostUuid
     * @return array|EntityInterface|null
     * @throws HostNotFoundException
     */
    public function getHost($hostUuid) {
        /** @var HostsTable $HostsTable */
        $HostsTable = TableRegistry::getTableLocator()->get('Hosts');

        $host = $HostsTable->find()
            ->where([
                'Hosts.uuid' => $hostUuid
            ])
            ->select([
                'Hosts.id',
                'Hosts.uuid',
                'Hosts.name',
                'Hosts.address',
                'Hosts.satellite_id'
            ])
            ->first();

        if (empty($host)) {
            throw new HostNotFoundException();
        }
        $host = $host->toArray();

        return $host;
    }

    /**
     * @param string $serviceUuid
     * @return array|EntityInterface|null
     * @throws ServiceNotFoundException
     */
    public function getService($serviceUuid) {
        /** @var ServicesTable $ServicesTable */
        $ServicesTable = TableRegistry::getTableLocator()->get('Services');

        $service = $ServicesTable->find()
            ->contain([
                'Hosts',
                'Servicetemplates'
            ])
            ->where([
                'Services.uuid' => $serviceUuid
            ])
            ->select([
                'Services.id',
                'Services.uuid',
                'Services.name',
                'Servicetemplates.id',
                'Servicetemplates.name',
                'Hosts.id',
                'Hosts.uuid',
                'Hosts.name',
                'Hosts.satellite_id'
            ])
            ->first();

        if (empty($service)) {
            throw new ServiceNotFoundException();
        }
        $service = $service->toArray();

        if ($service['name'] === null || $service['name'] === '') {
            $service['name'] = $service['servicetemplate']['name'];
        }

        return $service;
    }
}